#ifndef HW_ACPI_PIIX4_H
#define HW_ACPI_PIIX4_H

#define TYPE_PIIX4_PM "PIIX4_PM"

#endif
